@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -459,6 +459,26 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         r"""Returns a list of functions that belong to the
         requested project.
 
+
+        .. code-block:: python
+
+            from google.cloud import functions_v1
+
+            def sample_list_functions():
+                # Create a client
+                client = functions_v1.CloudFunctionsServiceClient()
+
+                # Initialize request argument(s)
+                request = functions_v1.ListFunctionsRequest(
+                )
+
+                # Make the request
+                page_result = client.list_functions(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.functions_v1.types.ListFunctionsRequest, dict]):
                 The request object. Request for the `ListFunctions`
@@ -519,6 +539,26 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         r"""Returns a function with the given name from the
         requested project.
 
+
+        .. code-block:: python
+
+            from google.cloud import functions_v1
+
+            def sample_get_function():
+                # Create a client
+                client = functions_v1.CloudFunctionsServiceClient()
+
+                # Initialize request argument(s)
+                request = functions_v1.GetFunctionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_function(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.functions_v1.types.GetFunctionRequest, dict]):
                 The request object. Request for the `GetFunction`
@@ -546,7 +586,7 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -596,6 +636,34 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         already exists in the specified project, the long running
         operation will return ``ALREADY_EXISTS`` error.
 
+
+        .. code-block:: python
+
+            from google.cloud import functions_v1
+
+            def sample_create_function():
+                # Create a client
+                client = functions_v1.CloudFunctionsServiceClient()
+
+                # Initialize request argument(s)
+                function = functions_v1.CloudFunction()
+                function.source_archive_url = "source_archive_url_value"
+
+                request = functions_v1.CreateFunctionRequest(
+                    location="location_value",
+                    function=function,
+                )
+
+                # Make the request
+                operation = client.create_function(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.functions_v1.types.CreateFunctionRequest, dict]):
                 The request object. Request for the `CreateFunction`
@@ -629,7 +697,7 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([location, function])
         if request is not None and has_flattened_params:
@@ -686,6 +754,32 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
     ) -> operation.Operation:
         r"""Updates existing function.
 
+        .. code-block:: python
+
+            from google.cloud import functions_v1
+
+            def sample_update_function():
+                # Create a client
+                client = functions_v1.CloudFunctionsServiceClient()
+
+                # Initialize request argument(s)
+                function = functions_v1.CloudFunction()
+                function.source_archive_url = "source_archive_url_value"
+
+                request = functions_v1.UpdateFunctionRequest(
+                    function=function,
+                )
+
+                # Make the request
+                operation = client.update_function(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.functions_v1.types.UpdateFunctionRequest, dict]):
                 The request object. Request for the `UpdateFunction`
@@ -713,7 +807,7 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([function])
         if request is not None and has_flattened_params:
@@ -773,6 +867,30 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         trigger, the trigger will be updated to remove this
         function.
 
+
+        .. code-block:: python
+
+            from google.cloud import functions_v1
+
+            def sample_delete_function():
+                # Create a client
+                client = functions_v1.CloudFunctionsServiceClient()
+
+                # Initialize request argument(s)
+                request = functions_v1.DeleteFunctionRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_function(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.functions_v1.types.DeleteFunctionRequest, dict]):
                 The request object. Request for the `DeleteFunction`
@@ -810,7 +928,7 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -869,6 +987,27 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         information on the actual limits, refer to `Rate
         Limits <https://cloud.google.com/functions/quotas#rate_limits>`__.
 
+
+        .. code-block:: python
+
+            from google.cloud import functions_v1
+
+            def sample_call_function():
+                # Create a client
+                client = functions_v1.CloudFunctionsServiceClient()
+
+                # Initialize request argument(s)
+                request = functions_v1.CallFunctionRequest(
+                    name="name_value",
+                    data="data_value",
+                )
+
+                # Make the request
+                response = client.call_function(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.functions_v1.types.CallFunctionRequest, dict]):
                 The request object. Request for the `CallFunction`
@@ -898,7 +1037,7 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
                 Response of CallFunction method.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, data])
         if request is not None and has_flattened_params:
@@ -973,6 +1112,25 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
 
         -  ``Authorization: Bearer YOUR_TOKEN``
 
+
+        .. code-block:: python
+
+            from google.cloud import functions_v1
+
+            def sample_generate_upload_url():
+                # Create a client
+                client = functions_v1.CloudFunctionsServiceClient()
+
+                # Initialize request argument(s)
+                request = functions_v1.GenerateUploadUrlRequest(
+                )
+
+                # Make the request
+                response = client.generate_upload_url(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.functions_v1.types.GenerateUploadUrlRequest, dict]):
                 The request object. Request of `GenerateSourceUploadUrl`
@@ -1024,8 +1182,26 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         limited period and should be used within minutes after
         generation.
         For more information about the signed URL usage see:
-        https://cloud.google.com/storage/docs/access-
-        control/signed-urls
+        https://cloud.google.com/storage/docs/access-control/signed-urls
+
+
+        .. code-block:: python
+
+            from google.cloud import functions_v1
+
+            def sample_generate_download_url():
+                # Create a client
+                client = functions_v1.CloudFunctionsServiceClient()
+
+                # Initialize request argument(s)
+                request = functions_v1.GenerateDownloadUrlRequest(
+                )
+
+                # Make the request
+                response = client.generate_download_url(request=request)
+
+                # Handle the response
+                print(response)
 
         Args:
             request (Union[google.cloud.functions_v1.types.GenerateDownloadUrlRequest, dict]):
@@ -1076,6 +1252,26 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         r"""Sets the IAM access control policy on the specified
         function. Replaces any existing policy.
 
+
+        .. code-block:: python
+
+            from google.cloud import functions_v1
+
+            def sample_set_iam_policy():
+                # Create a client
+                client = functions_v1.CloudFunctionsServiceClient()
+
+                # Initialize request argument(s)
+                request = functions_v1.SetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = client.set_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
                 The request object. Request message for `SetIamPolicy`
@@ -1182,6 +1378,26 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         Returns an empty policy if the function exists and does
         not have a policy set.
 
+
+        .. code-block:: python
+
+            from google.cloud import functions_v1
+
+            def sample_get_iam_policy():
+                # Create a client
+                client = functions_v1.CloudFunctionsServiceClient()
+
+                # Initialize request argument(s)
+                request = functions_v1.GetIamPolicyRequest(
+                    resource="resource_value",
+                )
+
+                # Make the request
+                response = client.get_iam_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
                 The request object. Request message for `GetIamPolicy`
@@ -1288,6 +1504,27 @@ class CloudFunctionsServiceClient(metaclass=CloudFunctionsServiceClientMeta):
         policy for a function. If the function does not exist, this will
         return an empty set of permissions, not a NOT_FOUND error.
 
+
+        .. code-block:: python
+
+            from google.cloud import functions_v1
+
+            def sample_test_iam_permissions():
+                # Create a client
+                client = functions_v1.CloudFunctionsServiceClient()
+
+                # Initialize request argument(s)
+                request = functions_v1.TestIamPermissionsRequest(
+                    resource="resource_value",
+                    permissions=['permissions_value_1', 'permissions_value_2'],
+                )
+
+                # Make the request
+                response = client.test_iam_permissions(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
                 The request object. Request message for
